==> jc-1.4.0.tar.gz: java/rmi/Naming.h <==
// public final class java.rmi.Naming

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 8cb21251e31bc78d java_rmi_Naming

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_rmi_Naming_H_
#define _JC_java_rmi_Naming_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_net_URL$object;
struct _jc_java_rmi_Remote$object;
struct _jc_java_rmi_registry_Registry$object;

// Typedefs
typedef struct _jc_java_rmi_Naming$sub_refs	_jc_java_rmi_Naming$sub_refs;
typedef struct _jc_java_rmi_Naming$sub_nonrefs	_jc_java_rmi_Naming$sub_nonrefs;
typedef struct _jc_java_rmi_Naming$refs	_jc_java_rmi_Naming$refs;
typedef struct _jc_java_rmi_Naming$nonrefs	_jc_java_rmi_Naming$nonrefs;
typedef struct _jc_java_rmi_Naming$object	_jc_java_rmi_Naming$object;

typedef const struct _jc_java_rmi_Naming$vmethods	_jc_java_rmi_Naming$vmethods;
typedef const struct _jc_java_rmi_Naming$vtable	_jc_java_rmi_Naming$vtable;
typedef const struct _jc_java_rmi_Naming$vtype	_jc_java_rmi_Naming$vtype;

// Constructors
extern void _jc_java_rmi_Naming$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_rmi_Naming$object *);

// Static methods
extern void _jc_java_rmi_Naming$method$bind$251a9c112e05991e(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_object *);
extern struct _jc_object *_jc_java_rmi_Naming$method$getRegistry$5ad42409714c962d(_jc_env *, struct _jc_java_net_URL$object *);
extern _jc_object_array *_jc_java_rmi_Naming$method$list$316ea7d03067710f(_jc_env *, struct _jc_java_lang_String$object *);
extern struct _jc_object *_jc_java_rmi_Naming$method$lookup$c76567b1fb804127(_jc_env *, struct _jc_java_lang_String$object *);
extern void _jc_java_rmi_Naming$method$rebind$082655182723d0d0(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_object *);
extern void _jc_java_rmi_Naming$method$unbind$6f23bcd0c5499698(_jc_env *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_rmi_Naming$vmethods {
};

// Vtable
struct _jc_java_rmi_Naming$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_rmi_Naming$vmethods	java_rmi_Naming;
};

// Vtype
struct _jc_java_rmi_Naming$vtype {
	_jc_type			type;
	_jc_java_rmi_Naming$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_Naming$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_rmi_Naming$refs {
    _jc_java_rmi_Naming$sub_refs	java_rmi_Naming;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_Naming$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_Naming$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_rmi_Naming$sub_nonrefs	java_rmi_Naming;
};

// Object instance structure
struct _jc_java_rmi_Naming$object {
	_jc_java_rmi_Naming$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_Naming$vtype	*vtype;
	_jc_java_rmi_Naming$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_Naming$vtype _jc_java_rmi_Naming$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_Naming, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_Naming$class_object;

#endif	/* _JC_java_rmi_Naming_H_ */

==> jc-1.4.6.tar.gz: java/rmi/Naming.h <==
// public final class java.rmi.Naming

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 956a860f82cdd831 java_rmi_Naming

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_rmi_Naming_H_
#define _JC_java_rmi_Naming_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_net_URL$object;
struct _jc_java_rmi_Remote$object;
struct _jc_java_rmi_registry_Registry$object;

// Typedefs
typedef struct _jc_java_rmi_Naming$sub_refs	_jc_java_rmi_Naming$sub_refs;
typedef struct _jc_java_rmi_Naming$sub_nonrefs	_jc_java_rmi_Naming$sub_nonrefs;
typedef struct _jc_java_rmi_Naming$refs	_jc_java_rmi_Naming$refs;
typedef struct _jc_java_rmi_Naming$nonrefs	_jc_java_rmi_Naming$nonrefs;
typedef struct _jc_java_rmi_Naming$object	_jc_java_rmi_Naming$object;

typedef const struct _jc_java_rmi_Naming$vmethods	_jc_java_rmi_Naming$vmethods;
typedef const struct _jc_java_rmi_Naming$vtable	_jc_java_rmi_Naming$vtable;
typedef const struct _jc_java_rmi_Naming$vtype	_jc_java_rmi_Naming$vtype;

// Constructors
extern void _jc_java_rmi_Naming$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_rmi_Naming$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_java_rmi_Naming$method$bind$251a9c112e05991e(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_rmi_Naming$method$getName$5acdd90d5834e652(_jc_env *, struct _jc_java_net_URL$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_rmi_Naming$method$getRegistry$5ad42409714c962d(_jc_env *, struct _jc_java_net_URL$object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_java_rmi_Naming$method$list$316ea7d03067710f(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_rmi_Naming$method$lookup$c76567b1fb804127(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_net_URL$object *_jc_java_rmi_Naming$method$parseURL$5f0b9e7c615f0334(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_java_rmi_Naming$method$rebind$082655182723d0d0(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_java_rmi_Naming$method$unbind$6f23bcd0c5499698(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_rmi_Naming$vmethods {
};

// Vtable
struct _jc_java_rmi_Naming$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_rmi_Naming$vmethods	java_rmi_Naming;
};

// Vtype
struct _jc_java_rmi_Naming$vtype {
	_jc_type			type;
	_jc_java_rmi_Naming$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_Naming$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_rmi_Naming$refs {
    _jc_java_rmi_Naming$sub_refs	java_rmi_Naming;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_Naming$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_Naming$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_rmi_Naming$sub_nonrefs	java_rmi_Naming;
};

// Object instance structure
struct _jc_java_rmi_Naming$object {
	_jc_java_rmi_Naming$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_Naming$vtype	*vtype;
	_jc_java_rmi_Naming$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_Naming$vtype _jc_java_rmi_Naming$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_Naming, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_Naming$class_object;

#endif	/* _JC_java_rmi_Naming_H_ */
